@@ -36,8 +36,8 @@ class SlipcoverMetaPathFinder(MetaPathFinder):
         if self.args.debug:
             print(f"Looking for {fullname}")
         for f in self.meta_path:
-            found = f.find_spec(fullname, path, target)
-            if (found):
+            found = f.find_spec(fullname, path, target) if hasattr(f, 'find_spec') else None
+            if found:
                 if found.origin and file_matcher.matches(found.origin):
                     if self.args.debug:
                         print(f"adding {fullname} from {found.origin}")
@@ -156,7 +156,7 @@ def wrap_pytest():
 if not args.dont_wrap_pytest:
     wrap_pytest()
 
-sys.meta_path=[SlipcoverMetaPathFinder(args, sci, file_matcher, sys.meta_path)]
+sys.meta_path.insert(0, SlipcoverMetaPathFinder(args, sci, file_matcher, sys.meta_path.copy()))
 
 
 def print_coverage(outfile):
